@@ -29,7 +29,6 @@
 #include <signal.h>
 #include <time.h>
 #include <poll.h>
-#include <alsa/asoundlib.h>
 #include "alsactl.h"
 
 struct id_list {
@@ -80,6 +79,8 @@ static void card_free(struct card **card)
 {
 	struct card *c = *card;
 
+	if (c == NULL)
+		return;
 	free_list(&c->blacklist);
 	free_list(&c->whitelist);
 	if (c->handle)
@@ -284,7 +285,7 @@ static long read_pid_file(const char *pidfile)
 			err = err < 0 ? -errno : -EIO;
 		close(fd);
 		pid_txt[11] = '\0';
-		return atol(pid_txt);
+		return err < 0 ? err : atol(pid_txt);
 	} else {
 		return -errno;
 	}
