@@ -34,11 +34,26 @@
 
 static WINDOW *curses_initialized;
 
-static void black_hole_error_handler(const char *file, int line,
-				     const char *function, int err,
-				     const char *fmt, ...)
+#if SND_LIB_VER(1, 2, 15) < SND_LIB_VERSION
+static void black_hole_error_handler(const char *file ATTRIBUTE_UNUSED,
+				     int line ATTRIBUTE_UNUSED,
+				     const char *function ATTRIBUTE_UNUSED,
+				     int err ATTRIBUTE_UNUSED,
+				     const char *fmt ATTRIBUTE_UNUSED, ...)
 {
 }
+#else
+static void black_hole_log_handler(int prio ATTRIBUTE_UNUSED,
+				   int interface ATTRIBUTE_UNUSED,
+				   const char *file ATTRIBUTE_UNUSED,
+				   int line ATTRIBUTE_UNUSED,
+				   const char *function ATTRIBUTE_UNUSED,
+				   int errcode ATTRIBUTE_UNUSED,
+				   const char *fmt ATTRIBUTE_UNUSED,
+				   va_list arg ATTRIBUTE_UNUSED)
+{
+}
+#endif
 
 void initialize_curses(bool use_color, bool use_mouse)
 {
@@ -50,9 +65,14 @@ void initialize_curses(bool use_color, bool use_mouse)
 #endif
 	window_size_changed(); /* update screen_lines/cols */
 	init_colors(use_color);
-	if (use_mouse && has_mouse())
+	if (use_mouse)
 		mousemask(ALL_MOUSE_EVENTS, NULL);
+
+#if SND_LIB_VER(1, 2, 15) < SND_LIB_VERSION
 	snd_lib_error_set_handler(black_hole_error_handler);
+#else
+	snd_lib_log_set_handler(black_hole_log_handler);
+#endif
 }
 
 void app_shutdown(void)
