@@ -221,7 +221,7 @@ static int build_time_constant(unsigned int frames_per_second,
 			       unsigned int samples_per_frame, uint16_t *code,
 			       bool extended)
 {
-	int i;
+	unsigned int i;
 
 	// 16 bits are available for this purpose.
 	if (extended) {
@@ -234,7 +234,7 @@ static int build_time_constant(unsigned int frames_per_second,
 					frames_per_second)
 				break;
 		}
-		if (i < ARRAY_SIZE(ex_v110_time_consts) ||
+		if (i < ARRAY_SIZE(ex_v110_time_consts) &&
 		    frames_per_second <= 192000) {
 			*code = ex_v110_time_consts[i].code;
 		} else {
@@ -264,7 +264,7 @@ static unsigned int parse_time_constant(uint16_t code,
 					unsigned int *frames_per_second,
 					bool extended)
 {
-	int i;
+	unsigned int i;
 
 	if (extended) {
 		if (samples_per_frame > 2)
@@ -344,7 +344,7 @@ static int parse_container_header(struct parser_state *state,
 
 static bool check_code_id(uint8_t code_id, unsigned int version)
 {
-	int i;
+	unsigned int i;
 
 	for (i = 0; i < ARRAY_SIZE(format_maps); ++i) {
 		if (code_id != format_maps[i].code_id)
@@ -520,30 +520,32 @@ static int detect_format_block(struct container_context *cntr)
 {
 	struct parser_state *state = cntr->private_data;
 	struct block_header header;
-	void *buf = NULL;
+	void *buf;
 	int err;
 
 again:
+	buf = NULL;
 	err = cache_data_block(cntr, &header, &buf);
 	if (err < 0)
 		return err;
+	if (buf) {
+		if (header.type == BLOCK_TYPE_EXTENDED_V110_FORMAT) {
+			err = parse_extended_v110_format(state, buf);
+		} else if (header.type == BLOCK_TYPE_V120_DATA) {
+			err = parse_v120_format_block(state, buf);
+		} else if (header.type == BLOCK_TYPE_V110_DATA) {
+			err = parse_v110_data(state, buf);
+		} else {
+			free(buf);
+			goto again;
+		}
 
-	if (header.type == BLOCK_TYPE_EXTENDED_V110_FORMAT) {
-		err = parse_extended_v110_format(state, buf);
-	} else if (header.type == BLOCK_TYPE_V120_DATA) {
-		err = parse_v120_format_block(state, buf);
-	} else if (header.type == BLOCK_TYPE_V110_DATA) {
-		err = parse_v110_data(state, buf);
-	} else {
 		free(buf);
-		goto again;
+
+		if (err < 0)
+			return err;
 	}
 
-	free(buf);
-
-	if (err < 0)
-		return err;
-
 	// Expect to detect block_v110_data.
 	if (header.type == BLOCK_TYPE_EXTENDED_V110_FORMAT)
 		goto again;
@@ -558,7 +560,7 @@ static int voc_parser_pre_process(struct container_context *cntr,
 				  uint64_t *byte_count)
 {
 	struct parser_state *state = cntr->private_data;
-	int i;
+	unsigned int i;
 	int err;
 
 	err = detect_container_version(cntr);
@@ -620,8 +622,8 @@ static int write_v120_format_block(struct container_context *cntr,
 	build_block_data_size(block->size, 12 + byte_count);
 
 	block->frames_per_second = htole32(frames_per_second);
-	block->bits_per_sample = htole16(state->bytes_per_sample * 8);
-	block->samples_per_frame = htole16(state->samples_per_frame);
+	block->bits_per_sample = state->bytes_per_sample * 8;
+	block->samples_per_frame = state->samples_per_frame;
 	block->code_id = htole16(state->code_id);
 
 	return container_recursive_write(cntr, block, sizeof(*block));
@@ -717,7 +719,7 @@ static int voc_builder_pre_process(struct container_context *cntr,
 				   uint64_t *byte_count)
 {
 	struct builder_state *state = cntr->private_data;
-	int i;
+	unsigned int i;
 
 	// Validate parameters.
 	for (i = 0; i < ARRAY_SIZE(format_maps); ++i) {
@@ -773,7 +775,7 @@ static int write_block_terminator(struct container_context *cntr)
 static int write_data_size(struct container_context *cntr, uint64_t byte_count)
 {
 	struct builder_state *state = cntr->private_data;
-	off64_t offset;
+	off_t offset;
 	uint8_t size_field[3];
 	int err;
 
