@@ -78,7 +78,7 @@ static int timer_mmap_pre_process(struct libasound_state *state)
 			return err;
 
 		logging(state, "attributes for mapped page frame:\n");
-		for (i = 0; i < layout->samples_per_frame; ++i) {
+		for (i = 0; i < (int)layout->samples_per_frame; ++i) {
 			const snd_pcm_channel_area_t *area = areas + i;
 
 			logging(state, "  sample number: %d\n", i);
@@ -105,7 +105,7 @@ static void *get_buffer(struct libasound_state *state,
 		frame_buf = buf;
 	} else {
 		int i;
-		for (i = 0; i < layout->samples_per_frame; ++i) {
+		for (i = 0; i < (int)layout->samples_per_frame; ++i) {
 			layout->vector[i] = areas[i].addr;
 			layout->vector[i] += snd_pcm_samples_to_bytes(
 						state->handle, frame_offset);
@@ -171,7 +171,8 @@ static int timer_mmap_process_frames(struct libasound_state *state,
 		// exactly the mechanism yet.
 		err = xfer_libasound_wait_event(state, timeout_msec,
 						&revents);
-		if (err < 0)
+		// MEMO: timeout is expected since the above call is just to measure time elapse.
+		if (err < 0 && err != -ETIMEDOUT)
 			return err;
 		if (revents & POLLERR) {
 			// TODO: error reporting.
@@ -187,7 +188,7 @@ static int timer_mmap_process_frames(struct libasound_state *state,
 		avail = snd_pcm_avail(state->handle);
 		if (avail < 0)
 			return (int)avail;
-		if (avail < planned_count) {
+		if (avail < (snd_pcm_sframes_t)planned_count) {
 			logging(state,
 				"Wake up but not enough space: %lu %lu %u\n",
 				planned_count, avail, timeout_msec);
