@@ -20,6 +20,8 @@
  * stable indefinitely
  */
 
+#include "aconfig.h"
+
 #include <stdio.h>
 #include <stddef.h>
 #include <stdlib.h>
@@ -75,7 +77,7 @@ float sin_generator_next_sample(struct sin_generator *sg)
 	sg->state_real = sr * pr - si * pi;
 	sg->state_imag = sr * pi + pr * si;
 	/* return the input value so sine wave starts at exactly 0.0 */
-	return sr;
+	return (float)sr;
 }
 
 /* fills a vector with a sine wave */
@@ -109,7 +111,8 @@ static int reorder(struct bat *bat, float *val, int frames)
 	return 0;
 }
 
-static int adjust_waveform(struct bat *bat, float *val, int frames)
+static int adjust_waveform(struct bat *bat, float *val, int frames,
+		int channels)
 {
 	int i, nsamples, max;
 	float factor, offset = 0.0;
@@ -134,7 +137,7 @@ static int adjust_waveform(struct bat *bat, float *val, int frames)
 	}
 
 	factor = max * RANGE_FACTOR;
-	nsamples = bat->channels * frames;
+	nsamples = channels * frames;
 
 	for (i = 0; i < nsamples; i++)
 		val[i] = val[i] * factor + offset;
@@ -168,16 +171,35 @@ int generate_sine_wave(struct bat *bat, int frames, void *buf)
 	/* reorder samples to interleaved mode */
 	err = reorder(bat, sinus_f, frames);
 	if (err != 0)
-		return err;
+		goto exit;
 
 	/* adjust amplitude and offset of waveform */
-	err = adjust_waveform(bat, sinus_f, frames);
+	err = adjust_waveform(bat, sinus_f, frames, bat->channels);
 	if (err != 0)
-		return err;
+		goto exit;
 
 	bat->convert_float_to_sample(sinus_f, buf, frames, bat->channels);
 
+exit:
 	free(sinus_f);
 
-	return 0;
+	return err;
+}
+
+/* generate single channel sine waveform without sample conversion */
+int generate_sine_wave_raw_mono(struct bat *bat, float *buf,
+		float freq, int nsamples)
+{
+	int err = 0;
+	struct sin_generator sg;
+
+	err = sin_generator_init(&sg, 1.0, freq, bat->rate);
+	if (err < 0)
+		return err;
+	sin_generator_vfill(&sg, buf, nsamples);
+
+	/* adjust amplitude and offset of waveform */
+	err = adjust_waveform(bat, buf, nsamples, 1);
+
+	return err;
 }
